summaryrefslogtreecommitdiffstats
path: root/ui/gfx/blit.h
diff options
context:
space:
mode:
Diffstat (limited to 'ui/gfx/blit.h')
-rw-r--r--ui/gfx/blit.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/ui/gfx/blit.h b/ui/gfx/blit.h
index 01fa4f3..616fda3 100644
--- a/ui/gfx/blit.h
+++ b/ui/gfx/blit.h
@@ -40,12 +40,12 @@ UI_EXPORT void BlitCanvasToCanvas(SkCanvas *dst_canvas,
SkCanvas *src_canvas,
const Point& src_origin);
// Scrolls the given subset of the given canvas by the given amount.
// The canvas should not have a clip or a transform applied, since platforms
// may implement those operations differently.
UI_EXPORT void ScrollCanvas(SkCanvas* canvas,
const Rect& clip,
- const Vector2d& amount);
+ const Vector2d& offset);
} // namespace gfx
@@ -40,12 +40,12 @@ UI_EXPORT void BlitCanvasToCanvas(SkCanvas *dst_canvas,
SkCanvas *src_canvas,
const Point& src_origin);
-// Scrolls the given subset of the given canvas by the given amount.
+// Scrolls the given subset of the given canvas by the given offset.
// The canvas should not have a clip or a transform applied, since platforms
// may implement those operations differently.